library(ggplot2)
library(data.table)

x <- fread(file="blocking.csv")

# Remove this URL as there are few entries for it.
x <- x[url != "http://wayback.archive.org"]

x$anomaly_type <- ifelse(x$blocked == "false", "none", x$blocking_type)
x$anomaly_type <- relevel(factor(x$anomaly_type), "none")

# Sort countries first by anomaly rates, then by number of measurements.
counts <- x[, .(anomalous=sum(anomaly_type != "none"), total=.N), by=country]
x$country <- factor(x$country, levels=counts$country[
	order(-counts$anomalous/counts$total, -counts$total, counts$country)
])

cat(sprintf("%d countries\n", nrow(counts)))
counts[, percent_anomalous:=sprintf("%.1f%%", anomalous/total*100)]
counts[rev(order(anomalous/total))][anomalous > 0]

p <- ggplot(x)
p <- p + geom_bar(aes(x=country, group=anomaly_type, fill=anomaly_type),
	position=position_stack(reverse=TRUE))
p <- p + facet_grid(url ~ .)
p <- p + scale_fill_manual(values=c("gray", "red", "darkgreen", "coral"))
p <- p + theme_minimal()
p <- p + theme(legend.position="top")
p <- p + theme(axis.text.x=element_text(size=6))
p <- p + labs(y="number of measurements", title=sprintf("Anomalous measurements of archive.org by country, %s to %s",
	strftime(min(x$date), "%Y-%m-%d"),
	strftime(max(x$date), "%Y-%m-%d")))

ggsave("blocking.png", p, width=9, height=6, dpi=120)
